@@ -35,7 +35,7 @@ def selenium_driver(driver_type: DriverType, version: Optional[str] = None) -> p
         if headless:
             options.add_argument('--headless=new')
         return webdriver.Chrome(service=service, options=options)
-    elif driver_type == 'gecko' and not os.access(download_file, os.X_OK):
+    elif driver_type == 'firefox' and not os.access(download_file, os.X_OK):
         # make executable
         download_file.chmod(download_file.stat().st_mode | 0o111)
         
@@ -47,4 +47,5 @@ def selenium_driver(driver_type: DriverType, version: Optional[str] = None) -> p
         if headless:
             options.add_argument('--headless')
         return webdriver.Firefox(service=service, options=options)
+    raise ValueError(f"Unsupported driver type: {driver_type}")
     
\ No newline at end of file
